/* ------------------------------------------------------------------ */
/* REXXCC.CMD - a tiny REXX "compiler" (c) Bernd Schemmer 1994        */
/*                                                                    */
/* Usage:                                                             */
/*                                                                    */
/* 1. execute your REXX file to get the tokenized version of the      */
/* program                                                            */
/*                                                                    */
/* 2. call REXXCC to "compile" your REXX file.                        */
/* The syntax for REXXCC is:                                          */
/*                                                                    */
/*   REXXCC source TO target {WITH copyrightFile}                     */
/*                                                                    */
/* with:                                                              */
/*   source                                                           */
/*     is the name of the source file                                 */
/*     The extension of the name of the source file must be '.CMD'.   */
/*   target                                                           */
/*     is the name of the target file or directory                    */
/*     The extension for the target file must be '.CMD'. If you ommit */
/*     the extension, REXXCC appends '.CMD' to the name of the target */
/*     file. If you enter a directory name for this parameter, REXXCC */
/*     use the name of the source file for the name of the target     */
/*     file.                                                          */
/*   copyrightfile                                                    */
/*     is the file with the copyright message which replaces the      */
/*     original source code in the "compiled" version of the program. */
/*     If you ommit the parameter copyrightFile, REXXCC uses only its */
/*     copyright message as copyright file. If the copyright file is  */
/*     equal with the source file REXXCC uses the leading comment     */
/*     lines of the source file as copyright file.                    */
/*                                                                    */
/* See also the Notes below                                           */
/*                                                                    */
/* initial release: 01.07.1994 /bs                                    */
/* last Update:     13.07.1994 /bs                                    */
/*                                                                    */
/* Author                                                             */
/*   Bernd Schemmer                                                   */
/*   Baeckerweg 48                                                    */
/*   60316 Frankfurt                                                  */
/*   Germany                                                          */
/*   Phone: +49 (0) 69 4 97 04 84 (only MEZ after 18:00)              */
/*          or                                                        */
/*          +49 (0) 69 4 910 6 8107 (only MEZ between 8:00 and 17:00) */
/*                                                                    */
/* History                                                            */
/*                                                                    */
/*   V1.00  - 05.07.1994 /bs - inital release                         */
/*   V1.01  - 12.07.1994 /bs - added code to check if the temporary   */
/*                             path exists                            */
/*                           - change meaning of the 2nd parameter -- */
/*                             now it can be a directory name or a    */
/*                             file name                              */
/*                           - added code to check if the source file */
/*                             was changed after the last execution   */
/*                           - added code to check if the current     */
/*                             ADDRESS() environment is the CMD       */
/*                                                                    */
/* Notes:                                                             */
/*                                                                    */
/* REXXCC can only "compile" files on a read/write medium. So if you  */
/* want to "compile" a REXX file from a read-only medium (a CD for    */
/* example) you MUST copy it to a read/write medium (e.g. a hard      */
/* disk) and execute it there before compiling it!                    */
/*                                                                    */
/* The copyright file must begin with a valid REXX comment in line 1  */
/* column 1.                                                          */
/*                                                                    */
/* REXXCC doesn't overwrite existing target files.                    */
/*                                                                    */
/* You should not use 'TO' or 'WITH' as name for any of the variabel  */
/* parameters for REXXCC.                                             */
/*                                                                    */
/* REXXCC needs the programs EAUTIL, ATTRIB and MORE to be in a       */
/* directory in the environment variable PATH.                        */
/*                                                                    */
/* Note that you MUST reExecute a source file after you changed it    */
/* before you can compile it!                                         */
/*                                                                    */
/* Known limitations:                                                 */
/*                                                                    */
/* You can only "compile" REXX file which are less than 64 K in       */
/* tokenized form. 64 K is the maximum length of the EAs in which the */
/* REXX interpreter stores the tokenized form of REXX programs.       */
/* (Note that the second length shown by the dir command is the       */
/* length of the EAs.)                                                */
/*                                                                    */
/* You should not use the function "SOURCELINE" in a program          */
/* "compiled" by REXXCC because there is no source code anymore :-).  */
/* You may use difficult lines in the source file and the copyright   */
/* file to distinguish between the original and the "compiled"        */
/* version using "SOURCELINE" while running your program.             */
/*                                                                    */
/* ------------------------------------------------------------------ */
/* Terms for using this version of REXXCC                             */
/*                                                                    */
/* This version of REXXCC is Freeware. You can use and share it as    */
/* long as you neither delete nor change any file or program in the   */
/* archiv!                                                            */
/* IT IS VERY IMPORTANT THAT YOU SHARE THIS PROGRAM ONLY WITH IT'S    */
/* EXTENDED ATTRIBUTES (EAs) - because without them it will not run!  */
/*                                                                    */
/* If you find REXXCC useful, your gift in any amount would be        */
/* appreciated.                                                       */
/*                                                                    */
/* Please direct your inquiries, complaints, suggestions, bug lists   */
/* etc. to the adress noted above.                                    */
/*                                                                    */
/* If you like and use REXXCC it would be nice if you send me a       */
/* postcard.                                                          */
/*                                                                    */
/* ------------------------------------------------------------------ */
/* Terms for distributing REXXCC                                      */
/* for vendors, sysops and others 'for-profit' distributors           */
/*                                                                    */
/* I encourage all shareware vendors, BBS sysops and other            */
/* 'for-profit' distributors to copy and distribute this version      */
/* of REXXCC subject to the following restrictions:                   */
/*                                                                    */
/*  The REXXCC freeware package - including all related program files */
/*  and documentation files - cannot be modified in any way (other    */
/*  than that mentioned below) and must be distributed as a complete  */
/*  package, without exception.                                       */
/*                                                                    */
/*  Small additions to the package, such as the introductory or       */
/*  installation batch files used by many shareware disk vendors, are */
/*  acceptable.                                                       */
/*                                                                    */
/*  You may charge a distribution fee for the package, but you must   */
/*  not represent in any way that you are selling the software itself.*/
/*                                                                    */
/*  The disk-based documentation may not be distributed in printed    */
/*  form without the prior written permission of the author.          */
/*                                                                    */
/*  You shall not use, copy, rent, lease, sell, modify, decompile,    */
/*  disassemble, otherwise reverse engineer, or transfer this         */
/*  program except as provided in this agreement. Any such unautho-   */
/*  rized use shall result in immediate and automatic termination of  */
/*  the permission to distribute this program.                        */
/*                                                                    */
/*  I reserve the right to withdraw permission from any vendor to     */
/*  distribute my products at any time and for any reason.            */
/*                                                                    */
/* ------------------------------------------------------------------ */
/* Warranty Disclaimer                                                */
/*                                                                    */
/* Bernd Schemmer makes no warranty of any kind, expressed or         */
/* implied, including without limitation any warranties of            */
/* merchantability and/or fitness for a particular purpose.           */
/*                                                                    */
/* In no event will Bernd Schemmer be liable to you for any           */
/* additional damages, including any lost profits, lost savings, or   */
/* other incidental or consequential damages arising from the use of, */
/* or inability to use, this software and its accompanying documen-   */
/* tation, even if Bernd Schemmer has been advised of the possibility */
/* of such damages.                                                   */
/*                                                                    */
/* ------------------------------------------------------------------ */
/* Copyright                                                          */
/*                                                                    */
/* REXXCC, the documentation for REXXCC and all other related files   */
/* are Copyright 1994 by Bernd Schemmer                               */
/*                                                                    */
/* All rights reserved.                                               */
/*                                                                    */
/**********************************************************************/
/* compiled on 07/13/94 at 15:30:27 with REXXCC V1.01 (c) Bernd Schemmer 1994 */
